package com.zanxiang.game.module.manage.task;

import com.zanxiang.game.module.manage.service.IAppletCheckService;
import com.zanxiang.module.redis.service.IDistributedLockComponent;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.concurrent.TimeUnit;

/**
 * @author : lingfeng
 * @time : 2024-01-20
 * @description : 支付应用任务
 */
@Slf4j
@Component
public class PayApplicationTask {

    @Autowired
    private IDistributedLockComponent distributedLockComponent;

    @Autowired
    private IAppletCheckService appletCheckService;

    /**
     * 小程序每分钟检查
     */
//    @Scheduled(cron = "0 0/1 * * * ?")
    public void payApplicationCheck() {
        String lockKey = "payApplicationCheck_lock";
        //上锁
        if (!distributedLockComponent.doLock(lockKey, 0L, 10L, TimeUnit.MINUTES)) {
            return;
        }
        log.error("小程序每分钟token监控定时器开始执行, time : {}", System.currentTimeMillis());
        try {
            //执行检测
            appletCheckService.payApplicationCheck();
        } catch (Exception e) {
            log.error("小程序每分钟token监控异常, e : {}", e.getMessage());
        } finally {
            //释放锁
            distributedLockComponent.unlock(lockKey);
        }
        log.error("小程序每分钟token监控定时器执行完成时间 , time  : {}", System.currentTimeMillis());
    }

}
